@@ -6,23 +6,31 @@
 
 #include "alarmchecker.h"
 
+#ifndef Q_OS_ANDROID
 #include <QDBusInterface>
 #include <QDBusConnection>
 #include <QDBusReply>
+#endif
+
 #include <QDebug>
 
 AlarmChecker::AlarmChecker(QObject *parent) : QObject {parent}
 {
+#ifndef Q_OS_ANDROID
     m_interface = new QDBusInterface {QStringLiteral("org.kde.kongressac"), QStringLiteral("/kongressac"), QStringLiteral("org.kde.kongressac"), QDBusConnection::sessionBus(), this};
+#endif
 }
 
 void AlarmChecker::scheduleAlarmCheck()
 {
+#ifndef Q_OS_ANDROID
     m_interface->call(QStringLiteral("scheduleAlarmCheck"));
+#endif
 }
 
 int AlarmChecker::active()
 {
+#ifndef Q_OS_ANDROID
     auto kongressacActive {false};
 
     QDBusReply<int> reply = m_interface->call(QStringLiteral("active"));
@@ -31,4 +39,7 @@ int AlarmChecker::active()
     }
 
     return kongressacActive;
+#else
+    return false;
+#endif
 }
